translate.search.terminology

Home | Trees | Indices | Help |
Translate Toolkit

Package translate :: Package search :: Module terminology |
[hide private]
[frames] | no frames]

# Module terminology

source code

A class that does terminology matching

Classes | [hide private]
| TerminologyComparer

Home | Trees | Indices | Help |
Translate Toolkit

Generated by Epydoc 3.0.1 on Wed May 12 18:05:31 2010 | http://epydoc.sourceforge.net